@@ -26,6 +26,7 @@ from uuid import UUID
 # See https://github.com/package-url/packageurl-python/issues/65
 from packageurl import PackageURL
 
+from cyclonedx.builder.this import this_component, this_tool
 from cyclonedx.model import (
     AttachedText,
     Copyright,
@@ -38,7 +39,6 @@ from cyclonedx.model import (
     Note,
     NoteText,
     Property,
-    Tool,
     XsUri,
 )
 from cyclonedx.model.bom import Bom, BomMetaData
@@ -87,8 +87,10 @@ from cyclonedx.model.impact_analysis import (
 )
 from cyclonedx.model.issue import IssueClassification, IssueType, IssueTypeSource
 from cyclonedx.model.license import DisjunctiveLicense, License, LicenseAcknowledgement, LicenseExpression
+from cyclonedx.model.lifecycle import LifecyclePhase, NamedLifecycle, PredefinedLifecycle
 from cyclonedx.model.release_note import ReleaseNotes
 from cyclonedx.model.service import Service
+from cyclonedx.model.tool import Tool, ToolRepository
 from cyclonedx.model.vulnerability import (
     BomTarget,
     BomTargetVersionRange,
@@ -494,9 +496,9 @@ def get_bom_with_component_setuptools_with_vulnerability() -> Bom:
             ],
             individuals=[get_org_contact_2()]
         ),
-        tools=[
-            Tool(vendor='CycloneDX', name='cyclonedx-python-lib')
-        ],
+        tools=ToolRepository(tools=(
+            Tool(vendor='CycloneDX', name='cyclonedx-python-lib'),
+        )),
         analysis=VulnerabilityAnalysis(
             state=ImpactAnalysisState.EXPLOITABLE, justification=ImpactAnalysisJustification.REQUIRES_ENVIRONMENT,
             responses=[ImpactAnalysisResponse.CAN_NOT_FIX], detail='Some extra detail'
@@ -533,6 +535,7 @@ def get_bom_just_complete_metadata() -> Bom:
             content='VGVzdCBjb250ZW50IC0gdGhpcyBpcyBub3QgdGhlIEFwYWNoZSAyLjAgbGljZW5zZSE='
         )
     )]
+    bom.metadata.lifecycles = [PredefinedLifecycle(LifecyclePhase.BUILD)]
     bom.metadata.properties = get_properties_1()
     return bom
 
@@ -1047,6 +1050,155 @@ def get_bom_with_multiple_licenses() -> Bom:
     )
 
 
+def get_bom_with_tools() -> Bom:
+    return _make_bom(
+        metadata=BomMetaData(
+            tools=(
+                this_tool(),
+                Tool(name='test-tool-b'),
+                Tool(vendor='example',
+                     name='test-tool-a',
+                     version='1.33.7',
+                     hashes=[HashType.from_composite_str(
+                         'sha256:adbbbe72c8f023b4a2d96a3978f69d94873ab2fef424e0298287c3368519c1a6')],
+                     external_references=[get_external_reference_1()],
+                     ),
+            )
+        )
+    )
+
+
+def get_bom_with_tools_with_component_migrate() -> Bom:
+    return _make_bom(
+        metadata=BomMetaData(
+            tools=ToolRepository(
+                components=(
+                    this_component(),
+                    Component(name='test-component', bom_ref='test-component'),
+                    Component(type=ComponentType.APPLICATION,
+                              bom_ref='other-component',
+                              group='acme',
+                              name='other-component',
+                              hashes=[HashType.from_composite_str(
+                                  'sha256:49b420bd8d8182542a76d4422e0c7890dcc88a3d8ddad04da06366d8c40ac8ca')],
+                              external_references=[get_external_reference_1()],
+                              ),
+                )
+            )
+        )
+    )
+
+
+def get_bom_with_tools_with_service_migrate() -> Bom:
+    return _make_bom(
+        metadata=BomMetaData(
+            tools=ToolRepository(
+                services=(
+                    Service(name='test-service', bom_ref='test-service'),
+                    Service(group='acme',
+                            name='other-service',
+                            bom_ref='other-service',
+                            external_references=[get_external_reference_1()],
+                            ),
+                )
+            )
+        )
+    )
+
+
+def get_bom_with_tools_with_component_and_service_migrate() -> Bom:
+    return _make_bom(
+        metadata=BomMetaData(
+            tools=ToolRepository(
+                components=(
+                    this_component(),
+                    Component(name='test-component', bom_ref='test-component'),
+                    Component(type=ComponentType.APPLICATION,
+                              bom_ref='other-component',
+                              group='acme',
+                              name='other-component',
+                              hashes=[HashType.from_composite_str(
+                                  'sha256:49b420bd8d8182542a76d4422e0c7890dcc88a3d8ddad04da06366d8c40ac8ca')],
+                              external_references=[get_external_reference_1()],
+                              ),
+                ),
+                services=(
+                    Service(name='test-service', bom_ref='test-service'),
+                    Service(group='acme',
+                            name='other-service',
+                            bom_ref='other-service',
+                            external_references=[get_external_reference_1()],
+                            ),
+                )
+            )
+        )
+    )
+
+
+def get_bom_with_tools_with_component_and_service_and_tools_irreversible_migrate() -> Bom:
+    tools = ToolRepository()
+    tcomp = tools.components
+    tserv = tools.services
+    ttools = tools.tools
+    tcomp.update((
+        this_component(),
+        Component(name='test-component', bom_ref='test-component'),
+        Component(type=ComponentType.APPLICATION,
+                  bom_ref='other-component',
+                  group='acme',
+                  name='other-component',
+                  hashes=[HashType.from_composite_str(
+                          'sha256:49b420bd8d8182542a76d4422e0c7890dcc88a3d8ddad04da06366d8c40ac8ca')],
+                  external_references=[get_external_reference_1()],
+                  ),
+    ))
+    tserv.update((
+        Service(name='test-service', bom_ref='test-service'),
+        Service(group='acme',
+                name='other-service',
+                bom_ref='other-service',
+                external_references=[get_external_reference_1()],
+                ),
+    ))
+    ttools.update((
+        this_tool(),
+        Tool(name='test-tool-b'),
+        Tool(vendor='example',
+             name='test-tool-a',
+             version='1.33.7',
+             hashes=[HashType.from_composite_str(
+                 'sha256:adbbbe72c8f023b4a2d96a3978f69d94873ab2fef424e0298287c3368519c1a6')],
+             external_references=[get_external_reference_1()],
+             ),
+    ))
+    return _make_bom(metadata=BomMetaData(tools=tools))
+
+
+def get_bom_with_tools_with_component_and_service_and_duplicated_tools_irreversible_migrate() -> Bom:
+    """on serialization, it is expected that only tools are emitted, and that they are deduplicated"""
+    tools = ToolRepository()
+    tcomp = tools.components
+    tserv = tools.services
+    ttools = tools.tools
+    tcomp.update((
+        this_component(),
+        Component(name='test-component'),
+        Component(type=ComponentType.APPLICATION,
+                  group='acme',
+                  name='other-component'),
+    ))
+    tserv.update((
+        Service(name='test-service'),
+        Service(group='acme',
+                name='other-service'),
+    ))
+    ttools.clear()
+    # duplicate components and services as tools
+    ttools.update(map(Tool.from_component, tcomp))
+    ttools.update(map(Tool.from_service, tserv))
+    return _make_bom(metadata=BomMetaData(tools=tools))
+
+
 def get_bom_for_issue_497_urls() -> Bom:
     """regression test for issue #497
     see https://github.com/CycloneDX/cyclonedx-python-lib/issues/497
@@ -1122,6 +1274,21 @@ def get_bom_for_issue_630_empty_property() -> Bom:
         )
     })
 
+
+def get_bom_with_lifecycles() -> Bom:
+    return _make_bom(
+        metadata=BomMetaData(
+            lifecycles=[
+                PredefinedLifecycle(LifecyclePhase.BUILD),
+                PredefinedLifecycle(LifecyclePhase.POST_BUILD),
+                NamedLifecycle(name='platform-integration-testing',
+                               description='Integration testing specific to the runtime platform'),
+            ],
+            component=Component(name='app', type=ComponentType.APPLICATION, bom_ref='my-app'),
+        ),
+    )
+
+
 # ---
 
 
@@ -1135,6 +1302,11 @@ all_get_bom_funct_valid_immut = tuple(
     if n.startswith('get_bom_') and not n.endswith('_invalid') and not n.endswith('_migrate')
 )
 
+all_get_bom_funct_valid_reversible_migrate = tuple(
+    (n, f) for n, f in getmembers(sys.modules[__name__], isfunction)
+    if n.startswith('get_bom_') and n.endswith('_migrate') and not n.endswith('_irreversible_migrate')
+)
+
 all_get_bom_funct_invalid = tuple(
     (n, f) for n, f in getmembers(sys.modules[__name__], isfunction)
     if n.startswith('get_bom_') and n.endswith('_invalid')
@@ -1162,4 +1334,5 @@ all_get_bom_funct_with_incomplete_deps = {
     get_bom_for_issue_598_multiple_components_with_purl_qualifiers,
     get_bom_with_component_setuptools_with_v16_fields,
     get_bom_for_issue_630_empty_property,
+    get_bom_with_lifecycles,
 }
